package WebGUI::i18n::Dutch::Asset_Thingy;
use utf8;
our $I18N = {
  'Creating column headers' => {
    'lastUpdated' => '1288950752',
    'message' => 'Kolomnamen aanmaken'
  },
  'Return to %s' => {
    'lastUpdated' => '1288950763',
    'message' => 'Ga terug naar %s.'
  },
  'Writing data' => {
    'lastUpdated' => '1288950773',
    'message' => 'Data schrijven'
  },
  'add field label' => {
    'lastUpdated' => '1205853556',
    'message' => 'Veld toevoegen'
  },
  'add label' => {
    'lastUpdated' => '1205853566',
    'message' => 'Toevoegen'
  },
  'add other thing label' => {
    'lastUpdated' => '1205853580',
    'message' => 'Voeg nog een object toe'
  },
  'add thing label' => {
    'lastUpdated' => '1206042264',
    'message' => 'Voeg Thing toe'
  },
  'addThing_url' => {
    'lastUpdated' => '1206042321',
    'message' => 'Dit URL leidt naar het scherm waar een nieuw Thing aan dit Thingy Asset kan worden toegevoegd.'
  },
  'add_url' => {
    'lastUpdated' => '1206042362',
    'message' => 'URL naar het toeveg scherm van dit Thing.'
  },
  'after save description' => {
    'lastUpdated' => '1206042391',
    'message' => 'Het scherm dat getoond wordt na het opslaan van dit Thing.'
  },
  'after save label' => {
    'lastUpdated' => '1206042407',
    'message' => 'Na opslaan'
  },
  'assetName' => {
    'lastUpdated' => '1205853615',
    'message' => 'Thingy'
  },
  'back to thingy default view' => {
    'lastUpdated' => '1228763503',
    'message' => 'Terug naar standaard Thingy scherm.'
  },
  'cache timeout' => {
    'lastUpdated' => '1205853635',
    'message' => 'Verlooptijd cache'
  },
  'cache timeout help' => {
    'lastUpdated' => '1205854024',
    'message' => '<p>Omdat alle gebruikers dit asset op dezelfde manier zien, kan het voor langere periode opgeslagen worden in het cache, zodat prestaties verbeterd worden. Hoe lang moet het in het cache opgeslagen worde?</p><p><strong>Gebruikers niveau:8</strong> </p>'
  },
  'callerAssetId' => {
    'lastUpdated' => '1311780656',
    'message' => 'Wanneer dit aan www_viewThingData meegegeven wordt, geeft dit het asstId van de beller. Wordt gebruikt door RenderThingMacro. Zie de POD in de code.'
  },
  'canEditThings' => {
    'lastUpdated' => '1206042541',
    'message' => 'Is waar wanneer de huidige gebruiker de Things kan bekijken die voor dit Thingy asset gedefini&euml;erd zijn.'
  },
  'canView' => {
    'lastUpdated' => '1213708355',
    'message' => 'Een functie die aangeeft of de huidige gebruiker de rechten heeft om dit Thing te bekijken.'
  },
  'check duplicates label' => {
    'lastUpdated' => '1205856140',
    'message' => 'Controleer duplikaten'
  },
  'default save button label' => {
    'lastUpdated' => '1206042554',
    'message' => 'Opslaan'
  },
  'default thing label' => {
    'lastUpdated' => '1206042568',
    'message' => 'Standaard Thing'
  },
  'default value description' => {
    'lastUpdated' => '1311780754',
    'message' => 'Voer de standaard waarde (indien deze er is) voor het veld. Wanneer de mogelijke waarden met behulp van een hash gedefini&euml;erd zijn, moet de standaardwaarde een key in de hash zijn. Voor Ja/Nee velden, voer &quot;ja&quot; in om &quot;Ja&quot; te selecteren en &quot;nee&quot; voor &quot;Nee&quot;. Voor datum/tijd velden kan een epoch datum of een datum in ISO 9601 format (JJJJ-MM-DD UU:MM:SS) ingevoerd worden, met de tijd optioneel.'
  },
  'default value label' => {
    'lastUpdated' => '1206042678',
    'message' => 'Standaard waarde'
  },
  'default value subtext' => {
    'lastUpdated' => '1206042720',
    'message' => '&Eacute;&eacute;n per regel'
  },
  'default view description' => {
    'lastUpdated' => '1206042790',
    'message' => 'Het standaard scherm voor dit Thing. Dit kan &oacute;f het zoekscherm &oacute;f het toevoeg scherm zijn.'
  },
  'default view label' => {
    'lastUpdated' => '1206046879',
    'message' => 'Standaard uiterlijk'
  },
  'delete label' => {
    'lastUpdated' => '1205856605',
    'message' => 'Verwijderen'
  },
  'delete thing data warning' => {
    'lastUpdated' => '1206046992',
    'message' => 'Weet u zeker dat u dit Thing wilt verwijderen? Hier wordt geen versie voor gemaakt en kan niet ongedaan worden gemaakt.'
  },
  'delete thing warning' => {
    'lastUpdated' => '1206046977',
    'message' => 'Weet u zeker dat u dit Thing en alle data erin wilt verwijderen? Hier wordt geen versie voor gemaakt en kan niet ongedaan worden gemaakt.'
  },
  'delete_confirm' => {
    'lastUpdated' => '1206047083',
    'message' => 'Dit bevat een functie naar de verwijder link die na klikken een javascript bevestiging laat zien.'
  },
  'delete_url' => {
    'lastUpdated' => '1206047109',
    'message' => 'Het URL om het huidige Thing te verwijderen.'
  },
  'display label' => {
    'lastUpdated' => '1205856170',
    'message' => 'Weergeven'
  },
  'displayInSearchFields_fieldId' => {
    'lastUpdated' => '1206047198',
    'message' => 'De veld identificatie van dit veld'
  },
  'displayInSearchFields_label' => {
    'lastUpdated' => '1206047224',
    'message' => 'Het label van dit veld'
  },
  'displayInSearchFields_loop' => {
    'lastUpdated' => '1206049934',
    'message' => 'Een functie die de velden bevat die getoond worden in de zoekresultaten.'
  },
  'displayInSearchFields_orderByUrl' => {
    'lastUpdated' => '1206049972',
    'message' => 'URL om de zoekresultaten te sorteren op dit veld.'
  },
  'duplicates label' => {
    'lastUpdated' => '1206050580',
    'message' => 'Wilt u nog duplicaten maken?'
  },
  'edit instructions description' => {
    'lastUpdated' => '1206050633',
    'message' => 'Instructies over het toevoegen of bewerken van een Thing op het bewerk scherm.'
  },
  'edit instructions label' => {
    'lastUpdated' => '1205856618',
    'message' => 'Instructies'
  },
  'edit label' => {
    'lastUpdated' => '1205856634',
    'message' => 'Bewerken'
  },
  'edit screen tab label' => {
    'lastUpdated' => '1205856648',
    'message' => 'Bewerk scherm'
  },
  'edit screen title description' => {
    'lastUpdated' => '1206050662',
    'message' => 'De titel van het bewerk scherm'
  },
  'edit screen title label' => {
    'lastUpdated' => '1205856667',
    'message' => 'Bewerk scherm titel'
  },
  'edit template description' => {
    'lastUpdated' => '1206050704',
    'message' => 'Bewerk sjabloon wordt gebruikt om het scherm van dit Thing te tonen.'
  },
  'edit template label' => {
    'lastUpdated' => '1205856183',
    'message' => 'Bewerk sjabloon'
  },
  'edit thing template label' => {
    'lastUpdated' => '1206450421',
    'message' => 'Thingy bewerk Thing sjabloon'
  },
  'edit thing title' => {
    'lastUpdated' => '1206050727',
    'message' => 'Bewerken/Toevoegen Thing'
  },
  'editInstructions' => {
    'lastUpdated' => '1206050749',
    'message' => 'Instructies over het bewerken van dit Thing'
  },
  'editScreenTitle' => {
    'lastUpdated' => '1206050768',
    'message' => 'De titel voor het bewerk scherm'
  },
  'edit_url' => {
    'lastUpdated' => '1206050855',
    'message' => 'URL naar het bewerk scherm voor de huidige Things'
  },
  'error_loop' => {
    'lastUpdated' => '1206051068',
    'message' => 'Een functie met fouten informatie, voor het geval dat iemand een verplichtveld niet invult.'
  },
  'error_message' => {
    'lastUpdated' => '1206051133',
    'message' => 'Een foutenbericht dat aangeeft wat de gebruiker fout gedaan zou kunnen hebben.'
  },
  'export label' => {
    'lastUpdated' => '1205855899',
    'message' => 'Exporteren'
  },
  'export metadata description' => {
    'lastUpdated' => '1224075830',
    'message' => 'Moet de exporteerfunctie de metadata zoals thingDataId, lastUpdated, ipAdress en dergelijke meenemen?'
  },
  'export metadata label' => {
    'lastUpdated' => '1224075843',
    'message' => 'Metadata exporteren?'
  },
  'export_url' => {
    'lastUpdated' => '1206051314',
    'message' => 'URL om de data van een zoekresultaat naar een csv bestand te exporten. Dit is alleen beschikbaar nadat een zoekopdracht is gedaan.'
  },
  'extras description' => {
    'lastUpdated' => '1206446764',
    'message' => 'Hier kunnen extra labels voor de veld labels ingevoerd worden. Bijvoorbeeld \'class=&quot;mijnKlasse&quot;\'.'
  },
  'extras label' => {
    'lastUpdated' => '1205855917',
    'message' => 'Extra\'s'
  },
  'field in other thing label' => {
    'lastUpdated' => '1206446776',
    'message' => 'Veld in ander Thing'
  },
  'field label description' => {
    'lastUpdated' => '1206446789',
    'message' => 'Het label van dit veld'
  },
  'field label label' => {
    'lastUpdated' => '1205856520',
    'message' => 'Label'
  },
  'field status description' => {
    'lastUpdated' => '1206446928',
    'message' => 'Verborgen velden zijn niet zichtbaar voor de gebuiker. Zichtbare velden kunnen wel gezien maar niet aangepast worden door de gebruiker. Bewerkbare&nbsp; velden kunnen ingevuld worden door de gebruiker. Verplichte of vereiste velden moeten door de gebruiker worden ingevuld. Als verborgen of zichtbare velden wordt gekozen, zorg dan dat er een standaard waarde ingevoerd wordt.'
  },
  'field status label' => {
    'lastUpdated' => '1205856677',
    'message' => 'Status'
  },
  'field type description' => {
    'lastUpdated' => '1206446986',
    'message' => 'Kies het type formulier onderdeel voor dit veld. Dit wordt ook gebruikt bij het valideren van alle invoer die de gebruiker levert.'
  },
  'field type label' => {
    'lastUpdated' => '1206447003',
    'message' => 'Type veld'
  },
  'field_form' => {
    'lastUpdated' => '1206447019',
    'message' => 'Het formulier onderdeel van dit veld.'
  },
  'field_id' => {
    'lastUpdated' => '1205856303',
    'message' => 'De identificatie van dit veld'
  },
  'field_isHidden' => {
    'lastUpdated' => '1205856363',
    'message' => 'Een functie die aangeeft of dit veld verborgen moet zijn.'
  },
  'field_isRequired' => {
    'lastUpdated' => '1205856381',
    'message' => 'Een functie die aangeeft of dit veld verplicht is.'
  },
  'field_isVisible' => {
    'lastUpdated' => '1206447055',
    'message' => 'Een functie die aangeeft of dit veld wel zichtbaar moet zijn, maar niet bewerkbaar.'
  },
  'field_label' => {
    'lastUpdated' => '1205855929',
    'message' => 'Het label van dit veld'
  },
  'field_loop' => {
    'lastUpdated' => '1206447083',
    'message' => 'Een functie die alle velden van dit Thing bevat.'
  },
  'field_name' => {
    'lastUpdated' => '1205856414',
    'message' => 'De naam van het formulier element voor dit veld.'
  },
  'field_pretext' => {
    'lastUpdated' => '1225914880',
    'message' => 'Een extra veld voor beschrijving, zodat gebruikers weten wat ze in het veld moeten invullen. Dit hoort boven of voor het formulierelement getoond te worden.'
  },
  'field_subtext' => {
    'lastUpdated' => '1225914923',
    'message' => 'Een omschrijving van het veld, zodat gebruikers weten wat er in het veld moet komen te staan. Dit hoort onder of na het formulierelement getoond te worden.'
  },
  'field_type' => {
    'lastUpdated' => '1242729546',
    'message' => 'Het type (bestand, tekst, etc.) van dit veld'
  },
  'field_url' => {
    'lastUpdated' => '1206447163',
    'message' => 'Een optioneel URL waar dit veld naar zou moeten linken. Dit wordt bijvoorbeeld gebruikt voor velden in andere Things.'
  },
  'field_value' => {
    'lastUpdated' => '1205856433',
    'message' => 'De waarde van dit veld'
  },
  'fields label' => {
    'lastUpdated' => '1205856685',
    'message' => 'Velden'
  },
  'fields tab label' => {
    'lastUpdated' => '1205856070',
    'message' => 'Velden'
  },
  'fieldstatus editable label' => {
    'lastUpdated' => '1206447171',
    'message' => 'Bewerkbaar'
  },
  'fieldstatus hidden label' => {
    'lastUpdated' => '1206447180',
    'message' => 'Verborgen'
  },
  'fieldstatus required label' => {
    'lastUpdated' => '1206447191',
    'message' => 'Verplicht'
  },
  'fieldstatus visible label' => {
    'lastUpdated' => '1206447199',
    'message' => 'Zichtbaar'
  },
  'file contains label' => {
    'lastUpdated' => '1206447210',
    'message' => 'Bestand bevat'
  },
  'form_end' => {
    'lastUpdated' => '1205855184',
    'message' => 'Het einde van het formulier'
  },
  'form_start' => {
    'lastUpdated' => '1206447223',
    'message' => 'Het start label van het formulier'
  },
  'form_submit' => {
    'lastUpdated' => '1206447256',
    'message' => 'Een formulier inzend knop, waarmee de data uit het formulier ingevoerd wordt.'
  },
  'has entered max per user message' => {
    'lastUpdated' => '1224075893',
    'message' => 'U heeft de maximum hoeveelheid bereikt.'
  },
  'height description' => {
    'lastUpdated' => '1206447298',
    'message' => 'Stel de hoogte van dit veld in in pixels. Dit wordt alleen gebruikt voor tekst en HTML gebieden.'
  },
  'height label' => {
    'lastUpdated' => '1205856078',
    'message' => 'Hoogte'
  },
  'height subtext' => {
    'lastUpdated' => '1206447316',
    'message' => 'Optioneel voor tekst en HTML gebieden.'
  },
  'ignore first line label' => {
    'lastUpdated' => '1206447329',
    'message' => 'Eerste regel negeren?'
  },
  'import file label' => {
    'lastUpdated' => '1205856710',
    'message' => 'Kies een bestand om te importeren.'
  },
  'import label' => {
    'lastUpdated' => '1205855885',
    'message' => 'Importeren'
  },
  'import_url' => {
    'lastUpdated' => '1206447503',
    'message' => 'URL voor het importeren van data in dit Thing vanuit een csv bestand.'
  },
  'is required error' => {
    'lastUpdated' => '1205856876',
    'message' => 'is verplicht'
  },
  'isCurrent' => {
    'lastUpdated' => '1213708406',
    'message' => 'Een functie die aangeeft of de gebruiker momenteel met dit Thing aan het werk is.'
  },
  'listOfThings' => {
    'lastUpdated' => '1213708443',
    'message' => 'Een functie die alle Things in dit Thingy in een lijst zet.'
  },
  'manage things label' => {
    'lastUpdated' => '1206447572',
    'message' => 'Beheer Things'
  },
  'manage_url' => {
    'lastUpdated' => '1206447563',
    'message' => 'Dit URL leidt naar een scherm waar de Things in dit Thingy asset beheerd kunnen worden.'
  },
  'max entries per user description' => {
    'lastUpdated' => '1224075928',
    'message' => 'Het aantal objecten dat een gebruiker aan dit thing kan toevoegen.'
  },
  'max entries per user label' => {
    'lastUpdated' => '1224075953',
    'message' => 'Max aantal objecten per gebruiker'
  },
  'name' => {
    'lastUpdated' => '1213708461',
    'message' => 'De naam van het Thing'
  },
  'no field values message' => {
    'lastUpdated' => '1206447596',
    'message' => 'Vld heeft geen enkele waarde.'
  },
  'no permission to edit' => {
    'lastUpdated' => '1222877047',
    'message' => 'U heeft niet voldoende permissies om dit Thing te bewerken.'
  },
  'no permission to search' => {
    'lastUpdated' => '1222877060',
    'message' => 'U heeft niet voldoende permissies om dit Thing te doorzoeken.<br /> '
  },
  'on add workflow description' => {
    'lastUpdated' => '1206447829',
    'message' => 'Workflow die in werking gezet wordt na het toevoegen van dit Thing.'
  },
  'on add workflow label' => {
    'lastUpdated' => '1206447843',
    'message' => 'Bij toevoegen'
  },
  'on delete workflow description' => {
    'lastUpdated' => '1206447871',
    'message' => 'Workflow die in werking wordt gezet na het verwijderen van dit Thing.'
  },
  'on delete workflow label' => {
    'lastUpdated' => '1206447882',
    'message' => 'Bij verwijderen'
  },
  'on edit workflow description' => {
    'lastUpdated' => '1206447923',
    'message' => 'Workflow die in werking wordt gezet na het bewerken van dit Thing.'
  },
  'on edit workflow label' => {
    'lastUpdated' => '1205856899',
    'message' => 'Bij bewerken'
  },
  'other thing field missing message' => {
    'lastUpdated' => '1231520426',
    'message' => 'Het veld van het andere Thing bestaat niet.'
  },
  'other thing missing message' => {
    'lastUpdated' => '1231520463',
    'message' => 'De Thing waar dit veld naar verwijst bestaat niet of heeft geen tabel of het betreffende veld is verwijderd.'
  },
  'overwrite label' => {
    'lastUpdated' => '1206447934',
    'message' => 'Overschrijven'
  },
  'owner' => {
    'lastUpdated' => '1254902552',
    'message' => 'Eigenaar'
  },
  'possible values description' => {
    'lastUpdated' => '1224076179',
    'message' => '<p>Dit veld veld wordt gebruikt voor de lijste typen (zoals aanvink lijsten en Selectie lijsten. Voer de waarden in die getoond moeten worden, &eacute;&eacute;n per regel.</p><p>Wanneer een ander label voor een waarde gewenst is, moeten de mogelijke waarden als volgt ingevoerd worden:</p><p>{</p><blockquote>&quot;key1&quot;=&gt;&quot;waarde1&quot;,<br />&quot;key2&quot;=&gt;&quot;waarde2&quot;,<br /> &quot;key3&quot;=&gt;&quot;waarde3&quot;,<br />...<br /></blockquote><p>{</p><p>Vergeet alle haakjes, komma\'s en dergelijke niet. Het enige wat gedaan moet worden is dat de key1 en waarde1 vervangen moeten worden door uw eigen naam/waarde paren. </p>'
  },
  'possible values label' => {
    'lastUpdated' => '1206447947',
    'message' => 'Mogelijke waarden'
  },
  'possible values subtext' => {
    'lastUpdated' => '1206447972',
    'message' => '&Eacute;&eacute;n per regel'
  },
  'pretext description' => {
    'lastUpdated' => '1225915018',
    'message' => 'Een uitbreiding van het label. Dit is extra informatie zoals een beschrijving van wat er in het veld ingevoerd moet worden of optionele instructies voor dit veld. Het zal boven of voor het formulierelement getoond worden.'
  },
  'pretext label' => {
    'lastUpdated' => '1225915156',
    'message' => 'Pre-tekst'
  },
  'save button label description' => {
    'lastUpdated' => '1206448006',
    'message' => 'Het label van de opslaan knop in het bewerk scherm.'
  },
  'save button label label' => {
    'lastUpdated' => '1206448019',
    'message' => 'Opslaan knop label'
  },
  'search button label' => {
    'lastUpdated' => '1206448039',
    'message' => 'Zoeken'
  },
  'search description description' => {
    'lastUpdated' => '1206448075',
    'message' => 'Omschrijving van het zoek scherm'
  },
  'search description label' => {
    'lastUpdated' => '1206448085',
    'message' => 'Omschrijving'
  },
  'search label' => {
    'lastUpdated' => '1205854110',
    'message' => 'Zoeken'
  },
  'search other thing label' => {
    'lastUpdated' => '1206448437',
    'message' => 'Doorzoek ander Thing:'
  },
  'search screen tab label' => {
    'lastUpdated' => '1206448446',
    'message' => 'Zoek scherm'
  },
  'search screen title description' => {
    'lastUpdated' => '1206448457',
    'message' => 'De titel van het zoek scherm'
  },
  'search screen title label' => {
    'lastUpdated' => '1206448467',
    'message' => 'Zoek scherm titel'
  },
  'search template description' => {
    'lastUpdated' => '1206448497',
    'message' => 'Dit sjabloon wordt gebruikt voor het weergeven van het zoek scherm van dit Thing.'
  },
  'search template label' => {
    'lastUpdated' => '1206448507',
    'message' => 'Zoek sjabloon'
  },
  'search thing label' => {
    'lastUpdated' => '1206448515',
    'message' => 'Zoeken'
  },
  'search thing template label' => {
    'lastUpdated' => '1206448532',
    'message' => 'Thingy zoek Thing sjabloon'
  },
  'search this thing label' => {
    'lastUpdated' => '1206448546',
    'message' => 'Doorzoek dit Thing'
  },
  'searchDescription' => {
    'lastUpdated' => '1206448560',
    'message' => 'Een omschrijving van het zoek scherm'
  },
  'searchFields_fieldId' => {
    'lastUpdated' => '1206449666',
    'message' => 'De veld identificatie van een doorzoekbaar veld.'
  },
  'searchFields_form' => {
    'lastUpdated' => '1206449710',
    'message' => 'Een formulier onderdeel dat overeenkomt met het veld type van dit veld, waar het veld op doorzocht moet worden.'
  },
  'searchFields_is__fieldType__' => {
    'lastUpdated' => '1206449952',
    'message' => 'Een functie die aangeeft of dit veld van een bepaald veldtype is . De eerste letter van __veldType__ is altijd een hoofdletter. Voorbeeld<br />voor een selectie vak is de waarde van &lt;tmpl_var searchFields_isSelectBox&gt; waar'
  },
  'searchFields_label' => {
    'lastUpdated' => '1206449969',
    'message' => 'Het label van een doorzoekbaar veld'
  },
  'searchFields_listType' => {
    'lastUpdated' => '1278062203',
    'message' => 'Een functie die waar is wanneer het veld van het type Lijst is.'
  },
  'searchFields_loop' => {
    'lastUpdated' => '1206449994',
    'message' => 'Een functie die de velden bevat die doorzoekbaar zijn.'
  },
  'searchFields_textForm' => {
    'lastUpdated' => '1206450035',
    'message' => 'Een tekst invoer waar dit veld op doorzocht moet worden.'
  },
  'searchResult_copy_icon' => {
    'lastUpdated' => '1242729654',
    'message' => 'Kopieer icoon voor het kopie&euml;ren van het zoekresultaat'
  },
  'searchResult_copy_url' => {
    'lastUpdated' => '1242729688',
    'message' => 'URL voor het kopi&euml;ren van het zoekresultaat'
  },
  'searchResult_delete_icon' => {
    'lastUpdated' => '1206450076',
    'message' => 'Verwijder icoon om dit zoek resultaat te verwijderen.'
  },
  'searchResult_delete_url' => {
    'lastUpdated' => '1242729708',
    'message' => 'URL voor het verwijderen van het zoekresultaat'
  },
  'searchResult_edit_icon' => {
    'lastUpdated' => '1206450185',
    'message' => 'Bewerk icoon die naar het bewerk scherm van dit zoek resultaat linkt.'
  },
  'searchResult_edit_url' => {
    'lastUpdated' => '1242729736',
    'message' => 'URL naar een scherm voor het aanpassen van het zoekresultaat'
  },
  'searchResult_field_loop' => {
    'lastUpdated' => '1206450223',
    'message' => 'Een functie die de velden bevat die getoond moeten worden voor dit zoekresultaat.'
  },
  'searchResult_id' => {
    'lastUpdated' => '1206450243',
    'message' => 'De identificatie van een zoekresultaat.'
  },
  'searchResult_json' => {
    'lastUpdated' => '1285166622',
    'message' => 'JSON gecodeerde versie van de searchResult_loop, zodat de data door Javascript gelezen kan worden.'
  },
  'searchResult_loop' => {
    'lastUpdated' => '1206952592',
    'message' => 'Een functie die de zoekresultaten bevat.'
  },
  'searchResult_view_url' => {
    'lastUpdated' => '1205855165',
    'message' => 'URL naar het scherm waar de zoekresultaten bekeken kunnen worden.'
  },
  'searchScreenTitle' => {
    'lastUpdated' => '1205855140',
    'message' => 'De titel van het zoekscherm'
  },
  'search_url' => {
    'lastUpdated' => '1205855030',
    'message' => 'URL dat naar het zoek scherm leidt.'
  },
  'size description' => {
    'lastUpdated' => '1205855123',
    'message' => 'Stel de grootte (breedte) in van de meeste velden in aantal karakters.'
  },
  'size label' => {
    'lastUpdated' => '1205854847',
    'message' => 'Grootte'
  },
  'skip label' => {
    'lastUpdated' => '1205854855',
    'message' => 'Overslaan'
  },
  'sort by label' => {
    'lastUpdated' => '1205854887',
    'message' => 'Sorteer op'
  },
  'subtext description' => {
    'lastUpdated' => '1225915204',
    'message' => 'Een uitbreiding van het label. Dit is extra informatie zoals een omschrijving van wat er in het veld moet komen of optionele instructies voor het veld. Dit wordt getoond onder of na het formulierelement.'
  },
  'subtext label' => {
    'lastUpdated' => '1205855003',
    'message' => 'Subtekst'
  },
  'template_label' => {
    'lastUpdated' => '1206448591',
    'message' => 'Thingy lijst sjabloon'
  },
  'thing must have fields' => {
    'lastUpdated' => '1222877089',
    'message' => 'Fout: Er moeten velden toegevoegd worden aan uw nieuwe Thing.'
  },
  'thing name description' => {
    'lastUpdated' => '1206448612',
    'message' => 'Een normaal leesbare naam voor dit Thing.'
  },
  'thing name label' => {
    'lastUpdated' => '1206448627',
    'message' => 'Naam Thing'
  },
  'thing_addUrl' => {
    'lastUpdated' => '1206448652',
    'message' => 'Een link naar het toevoeg scherm van dit Thing'
  },
  'thing_copyIcon' => {
    'lastUpdated' => '1242729802',
    'message' => 'Een icoon met een link voor het kopi&euml;ren van het Thing'
  },
  'thing_copyUrl' => {
    'lastUpdated' => '1242729847',
    'message' => 'Een link om het Thing te kopi&euml;ren'
  },
  'thing_deleteIcon' => {
    'lastUpdated' => '1206448676',
    'message' => 'Een icoon met een link om dit Thing te verwijderen.'
  },
  'thing_deleteUrl' => {
    'lastUpdated' => '1206448726',
    'message' => 'Een link om dit Thing te verwijderen'
  },
  'thing_editIcon' => {
    'lastUpdated' => '1206448755',
    'message' => 'Een icoon met een link naar het bewerk scherm van dit Thing.&nbsp;&nbsp;  '
  },
  'thing_editUrl' => {
    'lastUpdated' => '1206448779',
    'message' => 'Een link naar het bewerk scherm van dit Thing'
  },
  'thing_id' => {
    'lastUpdated' => '1206448797',
    'message' => 'De indentificatie van dit Thing'
  },
  'thing_label' => {
    'lastUpdated' => '1206448810',
    'message' => 'Het label van dit Thing'
  },
  'thing_searchUrl' => {
    'lastUpdated' => '1206448828',
    'message' => 'Een link naar het zoek scherm van dit Thing'
  },
  'thing_viewIcon' => {
    'lastUpdated' => '1206448853',
    'message' => 'Een icoon met een link naar het standaard scherm van dit Thing'
  },
  'things per page description' => {
    'lastUpdated' => '1206448877',
    'message' => 'Het aantal Things dat het zoek scherm per pagina toont.'
  },
  'things per page label' => {
    'lastUpdated' => '1206448888',
    'message' => 'Things per pagina'
  },
  'things_loop' => {
    'lastUpdated' => '1206448930',
    'message' => 'Een functie die alle Things in dit Thingy asset bevat, met links naar beheer functies voor die Things.'
  },
  'thingy asset template variables body' => {
    'lastUpdated' => '1206449092',
    'message' => 'Elk asset is voorzien van een set met variabelen voor het sjabloon, die zijn afgeleid van de interne asset eigenschappen. Sommige van deze variabelen kunnen nuttig zijn, anderen minder.'
  },
  'thingy asset template variables title' => {
    'lastUpdated' => '1206449112',
    'message' => 'Thingy asset sjabloon variabelen'
  },
  'thingy template description' => {
    'lastUpdated' => '1206449133',
    'message' => 'Kies een sjabloon voor dit Thingy.'
  },
  'thingy template label' => {
    'lastUpdated' => '1206449144',
    'message' => 'Thingy sjabloon'
  },
  'unique description' => {
    'lastUpdated' => '1311780579',
    'message' => 'Is dit een uniek veld? Met andere woorden, kan dezelfde waarde in deze kolom meer keren voorkomen?'
  },
  'unique label' => {
    'lastUpdated' => '1311780535',
    'message' => 'Uniek'
  },
  'variables by label' => {
    'lastUpdated' => '1304599751',
    'message' => 'Als toevoeging op de functie field_loop, kunnen veldwaarden direct aangesproken worden via het label. Raadpleeg de documentatie voor de sjabloon plugin die gebruikt wordt voor het verwerken van niet standaard karakters zoals spaties of aanhalingstekens in het label.'
  },
  'vertical description' => {
    'lastUpdated' => '1205854727',
    'message' => 'Deze eigenschap bepaalt of radio knoppen en aanvinklijsten horizontaal of vertikaal worden afgebeeld.'
  },
  'vertical label' => {
    'lastUpdated' => '1205854519',
    'message' => 'Vertikaal'
  },
  'view last edited label' => {
    'lastUpdated' => '1205854680',
    'message' => 'Bekijk laatst bewerkt/toegevoegd'
  },
  'view screen tab label' => {
    'lastUpdated' => '1205854657',
    'message' => 'Bekijk scherm'
  },
  'view screen title label' => {
    'lastUpdated' => '1205854535',
    'message' => 'Bekijk scherm titel'
  },
  'view template description' => {
    'lastUpdated' => '1206449457',
    'message' => 'Dit sjabloon wordt gebruikt voor het tonen van het bekijk-scherm van dit Thing'
  },
  'view template label' => {
    'lastUpdated' => '1206449447',
    'message' => 'Bekijk-sjabloon'
  },
  'view thing template label' => {
    'lastUpdated' => '1206449209',
    'message' => 'Thingy Thing sjabloon'
  },
  'view thingy default label' => {
    'lastUpdated' => '1206449478',
    'message' => 'Standaard Thingy'
  },
  'viewScreenTitle' => {
    'lastUpdated' => '1302256493',
    'message' => 'De titel voor het weergave scherm. Dit is een aaneensluiting van alle waarden van velden die de titel van het weergave scherm ingesteld hebben voor dit Thing. Als er geen velden ingesteld zijn, is dit veld leeg.'
  },
  'view_url' => {
    'lastUpdated' => '1228763556',
    'message' => 'Het URL dat de gebruiker terugneemt naar het standaard Thingy scherm.'
  },
  'who can add description' => {
    'lastUpdated' => '1206449496',
    'message' => 'De groep die dit Thing toe kan voegen'
  },
  'who can add label' => {
    'lastUpdated' => '1205854327',
    'message' => 'Wie kan toevoegen?'
  },
  'who can edit description' => {
    'lastUpdated' => '1224076342',
    'message' => '<p>Selecteer uit:</p><p>-\'eigenaar\' wanneer alleen degene die de data in dit thing heeft toegevoegd het mag bewerken</p><p>of</p><p>- een groep die alle data in dit thing kan bewerken</p><p>Een gebruiker die dit Thingy kan bewerken kan altijd alle data zien en bewerken.</p>'
  },
  'who can edit label' => {
    'lastUpdated' => '1205854317',
    'message' => 'Wie kan bewerken?'
  },
  'who can export description' => {
    'lastUpdated' => '1206449588',
    'message' => 'De groep die de data van dit Thing kan exporteren.'
  },
  'who can export label' => {
    'lastUpdated' => '1205854307',
    'message' => 'Wie kan exporteren?'
  },
  'who can import description' => {
    'lastUpdated' => '1206449615',
    'message' => 'De groep die data in dit Thing kan importeren.'
  },
  'who can import label' => {
    'lastUpdated' => '1205854295',
    'message' => 'Wie kan importeren?'
  },
  'who can search description' => {
    'lastUpdated' => '1206449630',
    'message' => 'De groep die dit Thing kan doorzoeken'
  },
  'who can search label' => {
    'lastUpdated' => '1205854197',
    'message' => 'Wie kan zoeken?'
  },
  'who can view description' => {
    'lastUpdated' => '1224076396',
    'message' => '<p>Selecteer uit:</p><p>-\'eigenaar\' wanneer alleen degene die de data in dit thing heeft toegevoegd het mag bekijken</p><p>of</p><p>- een groep die alle data in dit thing kan bekijken</p><p>Een gebruiker die dit Thingy wobject kan bewerken kan altijd alle data zien en bewerken.</p>'
  },
  'who can view label' => {
    'lastUpdated' => '1205854169',
    'message' => 'Wie kan bekijken?'
  },
  'width description' => {
    'lastUpdated' => '1205854159',
    'message' => 'Stel de breedte in in pixels van tekst-en HTML gebieden.'
  },
  'width label' => {
    'lastUpdated' => '1205854122',
    'message' => 'Breedte'
  }
}
;

1;
